Module blaxel.langgraph.tools
=============================

Functions
---------

`bl_tools(tools_names: list[str], **kwargs) ‑> list[langchain_core.tools.structured.StructuredTool]`
:   

`get_langchain_tool(tool: blaxel.core.tools.types.Tool) ‑> langchain_core.tools.structured.StructuredTool`
: